@@ -1,7 +1,8 @@
 #!/bin/sh
+export PATH='/usr/obj/hs-snap-core-0.9.6.4/bin:/usr/bin:/bin:/usr/sbin:/sbin:/usr/local/bin:/usr/local/bin:/usr/X11R6/bin'
 echo 'name: snap-core
-version: 0.9.4.0
-id: snap-core-0.9.4.0-aa42950ecf43ca25907a55a094e08299
+version: 0.9.6.4
+id: snap-core-0.9.6.4-03d78ae489a396c63027afffd7f00ac6
 
 license: BSD3
 copyright:
@@ -50,44 +51,44 @@ hidden-modules: Snap.Internal.Instances
                 Snap.Internal.Types Snap.Internal.Test.RequestBuilder
                 Snap.Internal.Test.Assertions
 trusted: False
-import-dirs: /usr/local/lib/ghc/snap-core-0.9.4.0
-library-dirs: /usr/local/lib/ghc/snap-core-0.9.4.0
-hs-libraries: HSsnap-core-0.9.4.0
+import-dirs: /usr/local/lib/ghc/snap-core-0.9.6.4
+library-dirs: /usr/local/lib/ghc/snap-core-0.9.6.4
+hs-libraries: HSsnap-core-0.9.6.4
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: HUnit-1.2.5.2-037d72e94f82e21ad0efc3a3ca13d5e2
-         MonadCatchIO-transformers-0.3.0.0-9df3c38f0408c0a91e2a32a7584ef9c9
-         attoparsec-0.10.4.0-fb379774679ae5734f1b536d33d902ec
-         attoparsec-enumerator-0.3.1-9799ee49c7c228079abd7930e5560145
-         base-4.6.0.1-185478ee9bcc4ae00bc1dbe06bac6937
-         blaze-builder-0.3.1.1-ac49b512143342e2370aead8ef93c70b
-         blaze-builder-enumerator-0.2.0.5-9ad1bc3197df6727c137d951b463129e
-         bytestring-0.10.0.2-fdb789c5db2e1ca48eb014403eee81b4
-         bytestring-mmap-0.2.2-ff6e08b3515cc82a6a1ab2ad8c28a870
-         case-insensitive-1.0.0.1-d2598685cbd81dd346ae8119d3bcded8
-         containers-0.5.0.0-3b8b869ec10d44736414ab5bea776319
-         deepseq-1.3.0.1-aa1be128186a233c7290faf88620ffe5
-         directory-1.2.0.1-5cea89dab5fade71d74e1fcf13ee5ca4
-         enumerator-0.4.19-af2193302e502a3821d2e5d25db7ea2c
-         filepath-1.3.0.1-edbc3d8247914b04f448e9261e7fe895
-         hashable-1.1.2.5-93ac9e8f4902e70447854e208345383a
-         mtl-2.1.2-735d9c92b4f214d454fb5168bb1eb6ee
-         random-1.0.1.1-de2c78bd5b6a198d2ecb982e7d11c02f
-         regex-posix-0.95.2-a34848eaff24ac32325260f99852c6c9
-         text-0.11.3.1-3fa3b4cb4ca4c0f49eeebe965c439ff9
-         time-1.4.0.1-11ddabfbdd9e1882a9135b100d37881b
-         unix-2.6.0.1-f31936082e1fa9175b93ddf28f79644c
-         unix-compat-0.4.1.1-7d1074b15de4b90d12292f611c87397a
-         unordered-containers-0.2.3.0-5bf92a1c1b90f6e2e5a5dbbd8a6ab013
-         vector-0.10.0.1-8398066fa66cdbff397fa1d47fe95cbe
-         zlib-enum-0.2.3-37dd2d636e8955ee1808dc2197600362
+depends: HUnit-1.2.5.2-787adf4463330986350e972335672d3e
+         MonadCatchIO-transformers-0.3.1.2-62247321324d3e4a539fd9759ef95eea
+         attoparsec-0.10.4.0-0ac2f673d8ce2452d1d5d7431ac6711d
+         attoparsec-enumerator-0.3.1-6ea1b5e76d86d8f3065a07373b7dc761
+         base-4.7.0.2-e1c96ce41208f09c293083d78870d5a2
+         blaze-builder-0.3.3.4-cc8529eae0cb63ae30a446e2fb6a0b82
+         blaze-builder-enumerator-0.2.0.5-b4313223d5a72f9228aa2526a332f837
+         bytestring-0.10.4.0-84f2b632cefc94e5dfeafb660607fcbd
+         bytestring-mmap-0.2.2-089613d8a75cc15b069776b275ade6d2
+         case-insensitive-1.1.0.3-9c8bdfaae18edea02ec088e971b0a08a
+         containers-0.5.5.1-d4bd887fb97aa3a46cbadc13709b7653
+         deepseq-1.3.0.2-63a1ab91b7017a28bb5d04cb1b5d2d02
+         directory-1.2.1.0-255ee2a4a618c74613f025ccc4ecc082
+         enumerator-0.4.20-ad119cc7a805e7f774e62a13ac0dd36f
+         filepath-1.3.0.2-25a474a9272ae6260626ce0d70ad1cab
+         hashable-1.2.2.0-6aae2a5ae00dba4cc06a8e388409e9ed
+         mtl-2.1.3.1-96f1a7910a7553352339ed05fb61c269
+         random-1.0.1.1-18033e0e7d0ae09dc4f8adbdce56b966
+         regex-posix-0.95.2-ed4992dd3310f21bd5691b3823fc6d4a
+         text-1.1.0.0-72236c81391c0a9a303f37559690d8fe
+         time-1.4.2-311aa8e77a6af87dc3d662d572df62ec
+         unix-2.7.0.1-49291e6beb52ca8844af5af8283d8383
+         unix-compat-0.4.1.1-3589aa38a14654855a07a6d23daf3b16
+         unordered-containers-0.2.4.0-2fd558fbd599b4e4c335e82ebd45f621
+         vector-0.10.9.1-1010d9fb05d5cbdd0bbbccafb8c8b174
+         zlib-enum-0.2.3-a30daa574694a0ee5f1b6ec3e2e94bde
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-snap-core-0.9.4.0/html/snap-core.haddock
-haddock-html: /usr/local/share/doc/hs-snap-core-0.9.4.0/html
+haddock-interfaces: /usr/local/share/doc/hs-snap-core-0.9.6.4/html/snap-core.haddock
+haddock-html: /usr/local/share/doc/hs-snap-core-0.9.6.4/html
 ' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
